/*
# Copyright (c) 2003-2004 by the University of Southern California.
# All rights reserved.
#
# Permission to use, copy, modify, and distribute this software and its
# documentation in source and binary forms for non-commercial purposes and
# without fee is hereby granted, provided that the above copyright notice
# appear in all copies and that both the copyright notice and this permission
# notice appear in supporting documentation, and that any documentation,
# advertising materials, and other materials related to such distribution and
# use acknowledge that the software was developed by the University of
# Southern California, Information Sciences Institute.  The name of the
# University may not be used to endorse or promote products derived from this
# software without specific prior written permission.
#
# THE UNIVERSITY OF SOUTHERN CALIFORNIA MAKES NO REPRESENTATIONS ABOUT THE
# SUITABILITY OF THIS SOFTWARE FOR ANY PURPOSE.  THIS SOFTWARE IS PROVIDED "AS
# IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT
# LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE.
#
# Other copyrights might apply to parts of this software and are so noted when
# applicable.
# ----------------------------------------------------------------------------
#
# Primary author: Purushotham Kamath
#                 Sept  2004
#This material is based upon work supported by the Defense Advanced Research 
#Projects Agency under contract no. N66001-02-1-8939 issued by the Space and 
#Naval Warfare Systems Center (SPAWAR).  Any opinions, findings, and conclusions 
#or recommendations expressed in this material are those of the author(s) and 
#do not necessarily reflect the views of the Defense Advanced Research Projects
#Agency, SPAWAR, or the U.S. Government.
*/



#include <stdarg.h>
#include <stdio.h>
#include <rng.h>
#include <packet.h>
#include <eventhandler.h>
#include <scheduler.h>

extern Scheduler *sched;


//Base class for a component that has to be scheduled by the scheduler.
//Any class which wants to have its events scheduled must be derived from this class.


EventHandler::~EventHandler()
{

}


//The event scheduling call back function. This function will be called 
//when an event of this event handler is due.

void EventHandler::handleevent(Packet *p)
{


}

void EventHandler::dtprintf(char * format, ...)
{
	if(debug)
	{
		printf("%.12f:",sched->currenttime);
		va_list ap;
		va_start(ap, format);
		vprintf(format, ap);
		fflush(stdout);
	}
}

void EventHandler::dprintf(char * format, ...)
{
	if(debug)
	{
		va_list ap;
		va_start(ap, format);
		vprintf(format, ap);
		fflush(stdout);
	}
}
